==> lin-cli-temp-custom-1.0.1.tgz: package/index.js <==
const fse = require('fs-extra')
const inquirer = require('inquirer')
const glob = require('glob')
const ejs = require('ejs')

async function install(info) {
  try {
    console.log('lin-cli-temp-custom')
    const descriptionPrompt = [{
      type: 'input',
      name: 'description',
      default: '',
      message: '请输入项目描述信息',
      validate: function (v) {
        const done = this.async();
        if (!v) {
          done('请输入项目描述信息！');
          return;
        }
        done(null, true);
      },
    }]
    const desc = await inquirer.prompt(descriptionPrompt)
    const {targetPath, sourcePath} = info
    fse.ensureDirSync(sourcePath)
    fse.ensureDirSync(targetPath)
    fse.copySync(sourcePath, targetPath)
    const options = {...info}
    await ejsRender(options)
  } catch (e) {
    throw e
  }
}

function ejsRender(options) {
  const globOpt = { ignore: options.templateInfo.ignores || '', nodir: true, cwd: options.targetPath}
  const ejsData = { ...options.templateInfo }
  return new Promise((resolve, reject) => {
    glob("**/*", globOpt, function (er, files) {
      if(er) {
        reject(er)
      }
      Promise.all(files.map((file) => {
        return new Promise((resolveItem, rejectItem) => {
          const dir = path.resolve(options.targetPath, file)
          ejs.renderFile(dir, ejsData, {}, function (err, res) {
            if (err) {
              rejectItem(err)
            } else {
              fse.writeFileSync(filePath, res)
              resolveItem(res)
            }
          })
        })
      }))
      .then(all => { resolve(all) })
      .catch(err => { reject(err) })
    })
  })
}

module.exports = install;

==> lin-cli-temp-custom-1.0.2.tgz: package/index.js <==
const fse = require('fs-extra')
const inquirer = require('inquirer')
const glob = require('glob')
const ejs = require('ejs')

async function install(info) {
  try {
    const descriptionPrompt = [{
      type: 'input',
      name: 'description',
      default: '',
      message: '请输入项目描述信息',
      validate: function (v) {
        const done = this.async();
        if (!v) {
          done('请输入项目描述信息！');
          return;
        }
        done(null, true);
      },
    }]
    const { description } = await inquirer.prompt(descriptionPrompt)
    const { targetPath, sourcePath } = info
    fse.ensureDirSync(sourcePath)
    fse.ensureDirSync(targetPath)
    fse.copySync(sourcePath, targetPath)
    const options = { ...info }
    options.projectInfo.description = description
      await ejsRender(options)
  } catch (e) {
    throw e
  }
}

function ejsRender(options) {
  console.log(options)
  const globOpt = { ignore: options.templateInfo.ignores || '', nodir: true, cwd: options.targetPath }
  const ejsData = { ...options.projectInfo }
  return new Promise((resolve, reject) => {
    glob("**/*", globOpt, function (er, files) {
      if (er) {
        reject(er)
      }
      Promise.all(files.map((file) => {
        return new Promise((resolveItem, rejectItem) => {
          const dir = path.resolve(options.targetPath, file)
          ejs.renderFile(dir, ejsData, {}, function (err, res) {
            if (err) {
              rejectItem(err)
            } else {
              fse.writeFileSync(dir, res)
              resolveItem(res)
            }
          })
        })
      }))
        .then(all => { resolve(all) })
        .catch(err => { reject(err) })
    })
  })
}

module.exports = install;
